@@ -1,11 +1,14 @@
 from .user import *  # noqa
 from .tweet import *  # noqa
 from .media import *  # noqa
+from .media_upload import *  # noqa
 from .poll import *  # noqa
 from .place import *  # noqa
 from .compliance import *  # noqa
 from .space import *  # noqa
 from .list import *  # noqa
 from .stream import *  # noqa
+from .trend import *  # noqa
 from .dm_event import *  # noqa
+from .usage import *  # noqa
 from .ext import *  # noqa
