@@ -1,7 +1,7 @@
 """
     Direct Message events
 
-    Refer: https://developer.twitter.com/en/docs/twitter-api/data-dictionary/object-model/dm-events
+    Refer: https://developer.x.com/en/docs/twitter-api/data-dictionary/object-model/dm-events
 """
 
 from dataclasses import dataclass, field
