@@ -1,8 +1,9 @@
 """
     tweet object
 
-    Refer: https://developer.twitter.com/en/docs/twitter-api/data-dictionary/object-model/tweet
+    Refer: https://developer.x.com/en/docs/twitter-api/data-dictionary/object-model/tweet
 """
+
 import textwrap
 from dataclasses import dataclass, field
 from typing import Optional, List
@@ -15,6 +16,9 @@ from .stream import StreamRule
 class TweetAttachments(BaseModel):
     poll_ids: Optional[List[str]] = field(default=None, repr=False, compare=False)
     media_keys: Optional[List[str]] = field(default=None, repr=False, compare=False)
+    media_source_tweet_id: Optional[List[str]] = field(
+        default=None, repr=False, compare=False
+    )
 
 
 @dataclass
@@ -40,7 +44,7 @@ class TweetEditControls(BaseModel):
 @dataclass
 class TweetContextAnnotation(BaseModel):
     """
-    Refer https://developer.twitter.com/en/docs/twitter-api/annotations
+    Refer https://developer.x.com/en/docs/twitter-api/annotations
     """
 
     domain: Optional[TweetContextAnnotationDomain] = field(
@@ -69,7 +73,7 @@ class TweetEntitiesHashtag(BaseModel):
 
 @dataclass
 class TweetEntitiesCashtag(TweetEntitiesHashtag):
-    ...
+    pass
 
 
 @dataclass
@@ -131,7 +135,7 @@ class TweetOrganicMetrics(TweetNonPublicMetrics):
 
 @dataclass
 class TweetPromotedMetrics(TweetOrganicMetrics):
-    ...
+    pass
 
 
 @dataclass
@@ -141,12 +145,13 @@ class TweetPublicMetrics(BaseModel):
     reply_count: Optional[int] = field(default=None, repr=False)
     like_count: Optional[int] = field(default=None)
     impression_count: Optional[int] = field(default=None, repr=False)
+    bookmark_count: Optional[int] = field(default=None, repr=False)
 
 
 @dataclass
 class TweetWithheld(BaseModel):
     """
-    refer: https://help.twitter.com/en/rules-and-policies/tweet-withheld-by-country
+    refer: https://help.x.com/en/rules-and-policies/tweet-withheld-by-country
     """
 
     copyright: Optional[bool] = field(default=None, repr=False)
@@ -159,6 +164,12 @@ class TweetReferencedTweet(BaseModel):
     id: Optional[str] = field(default=None, repr=False, compare=False)
 
 
+@dataclass
+class TweetNoteTweet(BaseModel):
+    text: Optional[str] = field(default=None, repr=False, compare=False)
+    entities: Optional[TweetEntities] = field(default=None, repr=False, compare=False)
+
+
 @dataclass
 class Tweet(BaseModel):
     """
@@ -203,6 +214,10 @@ class Tweet(BaseModel):
     reply_settings: Optional[str] = field(default=None, repr=False, compare=False)
     source: Optional[str] = field(default=None, repr=False, compare=False)
     withheld: Optional[TweetWithheld] = field(default=None, repr=False, compare=False)
+    note_tweet: Optional[TweetNoteTweet] = field(
+        default=None, repr=False, compare=False
+    )
+    community_id: Optional[str] = field(default=None, repr=False, compare=False)
 
     # Note: this field only for stream tweet
     matching_rules: Optional[List[StreamRule]] = field(
